digger v2.0.1 Digger.UpperCaser protocol

Documentation for Digger.UpperCaser Protocol

Link to this section Summary

Functions

Upper case the first letter of a valid Types.data_type according to the protocol implementation

Link to this section Types

Link to this section Functions

Link to this function upcase_first(data_type)

Upper case the first letter of a valid Types.data_type according to the protocol implementation